%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%                                       %%%
%%%   Style LaTeX pour les rapports de    %%%
%%%      L'Ecole des Mines de Douai       %%%
%%%                                       %%%
%%%      Aurlien Bompard (Gauret)        %%%
%%%     aurelien.bompard(at)free.fr       %%%
%%%            06/05/2003                 %%%
%%%                                       %%%
%%%   (Ce style est sous licence LaTeX)   %%%
%%%                                       %%%
%%%  Format de style adapt de report.cls %%%
%%%        et de rapport.cls              %%%
%%%   (http://www.nongnu.org/latexfr/)    %%%
%%%                                       %%%
%%%  UTILISATION :                        %%%
%%%  dbut-type de fichier :              %%%
%%%                                       %%%
%%%  \documentclass{emd}                  %%%
%%%  \begin{document}                     %%%
%%%  \author{\textsc{Aurlien Bompard}}   %%%
%%%  \promo{2003}                         %%%
%%%  \titre{Stage S3}                     %%%
%%%  \societe{MandrakeSoft}               %%%
%%%  \ville{Paris}                        %%%
%%%  \photo{logo}                         %%%
%%%  \photosize{3cm}                      %%%
%%%  \logos{isic}                         %%%
%%%  \oval OU \cadre OU \lignes           %%%
%%%                                       %%%
%%%  \maketitle OU \pagedetitre           %%%
%%%  \tableofcontents{} OU \tabledesmatieres{}
%%%                                       %%%
%%%  \chapter{Introduction}               %%%
%%%                                       %%%
%%%  \section{Gnralits}                %%%
%%%                                       %%%
%%%  Ensuite on peut utiliser :           %%%
%%%  chapter, section, subsection...      %%%
%%%                                       %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%  Version : 1.5

\NeedsTeXFormat{LaTeX2e} 
\ProvidesClass{emd}[2005/07/29 Aurelien Bompard pour les Mines de Douai] 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Options de la classe et chargement de la classe de rapports de base %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% Recto-verso
\DeclareOption{rectoverso}{
  \PassOptionsToClass{twoside}{report}
  \typeout{Attention : votre rapport sera recto-verso !}
}

% Dcorations de la page de titre et des chapitres.
\newif\ifcadre
\newif\iflignes
\newif\ifoval
% Par dfaut : lignes
\lignestrue
% affiche un cadre autour du titre
\DeclareOption{cadre}{\cadretrue \lignesfalse \ovalfalse}
% affiche des lignes autour du titre
\DeclareOption{lignes}{\cadrefalse \lignestrue \ovalfalse}
% affiche un oval autour du titre
\DeclareOption{oval}{\cadrefalse \lignesfalse \ovaltrue}

% Options par dfaut : police 12pt, papier A4, ouverture sur pages impaires.
\PassOptionsToClass{12pt,a4paper,openright}{report}

% Option inconnues : on les passe  "report"
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}

\ProcessOptions\relax

%%% Chargement de la classe report
\LoadClass{report} % format a4paper par dfaut 


%%%%%%%%%%%%%%%%%%%%% 
% Packages utiliss %
%%%%%%%%%%%%%%%%%%%%% 

%%% Chargement des Packages les plus courants 
\RequirePackage[T1]{fontenc}
\RequirePackage[latin1]{inputenc} % Pour pouvoir utiliser des accents dans le fichier texte
\RequirePackage[a4paper]{geometry} % Pour diminuer les marges
% \RequirePackage[margin=2.5cm]{geometry} % Pour rgler les marges plus prcisment.
\RequirePackage{graphicx} % Pour utiliser des images (package avanc)
\RequirePackage{setspace} % Pour rgler l'interligne
\RequirePackage[francais]{babel} % En franais (non sans dec ??)
\RequirePackage[french]{varioref} % Pour avoir de belles rfrences croises
\RequirePackage{fancyhdr} % En-ttes et pieds de page
\RequirePackage{marvosym} % Symbole \EUR
\RequirePackage{fancybox} % Encadrements
\RequirePackage{shadow} % Encadrements ombrs
\RequirePackage{url} % pour bien grer les URLs
% \RequirePackage{times} % Pour que le PDF passe bien avec Acrobat Reader (qui est buggu, putain de logiciel propritaire...)
\RequirePackage{ae,aecompl} % Pour que le PDF passe bien avec Acrobat Reader (qui est buggu, putain de logiciel propritaire...)
% \RequirePackage{pslatex} % Pour que le PDF passe bien avec Acrobat Reader (qui est buggu, putain de logiciel propritaire...)
\RequirePackage{moreverb} % mode verbatim amlior.
\RequirePackage[normalem]{ulem} % soulignement. Attention c'est pas bien normalement.
\RequirePackage{ifthen}
\RequirePackage[french]{nomencl}
\RequirePackage{index}

% \RequirePackage{lastpage}


%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%%% Reglages par defaut %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%% 

%%% En-ttes et pieds de page
\pagestyle{fancy}

%% Interligne un et demie
\onehalfspacing

%% initialiser le glossaire
\makeglossary

%% initialiser l'index
\makeindex

%% Virer les "Chapitre xxx" pour les en-ttes. Sinon a crit "Chapitre X" en haut des pages
\addto\captionsfrench{
  \renewcommand{\chaptername}{}  
}

%%% style sans serif pour les url
\urlstyle{sf}

%%% une profondeur de 2 pour la table des matires
\setcounter{tocdepth}{2}

%% Espace entre les paragraphes.
% \setlength{\parskip}{2ex}
\addtolength{\parskip}{0.5\baselineskip}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Dcoration des chapitres et de la page de titre %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% Commandes correspondantes pour 
% - garder la compatibilit
% - overrider (modifie le "theme"  partir de l'emplacement de la commande)
\def\cadre{\cadretrue \lignesfalse \ovalfalse}
\def\lignes{\cadrefalse \lignestrue \ovalfalse}
\def\oval{\cadrefalse \lignesfalse \ovaltrue}

% une commande pour faire moins gruik
\newcommand{\decoration}[2]{
  \ifoval\Ovalbox{#2}\fi
  \ifcadre\shadowbox{#2}\fi
  \iflignes
  {\hrule height 1pt}
  \vspace*{1mm}
  {\hrule height 0.1pt}
  \vspace*{#1}
  #2
  \vspace*{#1}
  {\hrule height 0.1pt}
  \vspace*{1mm}
  {\hrule height 1pt}
  \fi
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Commandes supplementaires %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% \auteur : dfinit l'auteur
\def\@auteur{} % Defaut : vide
\def\auteur#1{\def\@auteur{#1}}
% \promo : dfinit la promo de l'auteur
\def\@promo{}
\def\promo#1{\def\@promo{(promotion~#1)}}
% \titre : dfinit le titre
\def\@titre{}
\def\titre#1{\def\@titre{#1}}
% \societe : dfinit la socit
\def\@societe{}
\def\societe#1{\def\@societe{#1}}
% \ville : dfinit la ville.
\def\@ville{}
\def\ville#1{\def\@ville{(#1)}}
% \periode : dfinit la periode du stage. dbut et fin.
\def\@periode{}
\def\periode#1{\def\@periode{#1}}
% \option : Option  afficher en haut  droite
\def\@logos{\vspace*{6cm}} % defaut : zone vide de 7cm de haut
\def\option#1{\def\@logos{\logo{emd} \hfill \logo{#1}}}
% Choisir ses propres logos - dsactiv pour l'instant
% \def\logos#1{\def\@logos{#1}}
% \photo : afficher une photo (logo de l'entreprise par exemple)
\newif\ifphoto
\def\@titlephotoname{} % defaut : pas de photo de titre (nom vide)
\def\photo#1{\def\@titlephotoname{#1}\phototrue}
% \photosize : taille de la photo
\def\@photosize{8cm} % defaut : 8cm
\def\photosize#1{\def\@photosize{#1}}
% \htitre : titre  mettre dans les en-ttes.
\def\@htitre{}
\def\htitre#1{\def\@htitre{#1}}

% Commandes "franisant" les commandes LaTeX classiques
% note : autant utiliser les vrais commandes, mais bon...

\let\chapitre=\chapter
\let\partie=\part
\def\tabledesmatieres{\tableofcontents\thispagestyle{plain}}
% Les commandes classiques sont en fait les nouvelles commandes.
\renewcommand{\title}{\titre}
\renewcommand{\maketitle}{\pagedetitre}
\renewcommand{\author}{\auteur}


% \ligne : Trace une ligne de 3 cm centre
% \newcommand{\ligne}{%
%   \begin{center}\underline{\hspace{3cm}}\end{center}
%   \vspace*{5mm}}
% 
\newcommand{\ligne}{%
  \begin{center}\rule{3cm}{0.5pt}\end{center}
  % \vspace*{1cm}
}

% \endoneven : La dernire page sera paire
\newcommand{\MakeEndOnEven}{
  \if@openright
  \ifthenelse{\isodd{\thepage}}{\newpage \thispagestyle{empty} ~}{}
  \fi
}
\AtEndDocument{\MakeEndOnEven}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% On dfinit les hauts et pieds de pages
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

\fancyhf{}   % on efface tous les champs
\fancyhead[L]{\leftmark}
\fancyhead[R]{\@htitre}
\fancyfoot[C]{\thepage}
\renewcommand{\footrulewidth}{0pt}
\renewcommand{\headrulewidth}{0.1pt}

\fancypagestyle{plain}{%
  \fancyhf{}
  \fancyfoot[C]{\thepage}
  \renewcommand{\footrulewidth}{0pt}
  \renewcommand{\headrulewidth}{0pt}}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% On dfinit les logos utiliss %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

\def\logo#1{
  \ifthenelse{\equal{#1}{emd}}{\logoemd}{}
  \ifthenelse{\equal{#1}{isic}}{\logoisic}{}
  \ifthenelse{\equal{#1}{gip}}{\logogip}{}
  \ifthenelse{\equal{#1}{prod}}{\logoprod}{}
  \ifthenelse{\equal{#1}{ei}}{\logoei}{}
  \ifthenelse{\equal{#1}{chimie}}{\logochimie}{}
  \ifthenelse{\equal{#1}{mcm}}{\logomcm}{}
  \ifthenelse{\equal{#1}{mq}}{\logomq}{}
  \ifthenelse{\equal{#1}{tpc}}{\logotpc}{}
  \ifthenelse{\equal{#1}{gc}}{\logogc}{}
}

\newcommand{\logoemd}{%
  \begin{minipage}{5cm}\begin{center}%
      \includegraphics*[width=1.5cm]{emd}\\%
      \textsc{\'Ecole des Mines\\de Douai}
    \end{center}\end{minipage}
  \vspace*{2cm}
}

\newcommand{\logoisic}{
  \begin{minipage}{5cm}\begin{center}
      \vspace{1mm}
      \includegraphics[width=1.5cm]{gip}\\
      \large{\textsc{Option ISIC}}\vspace{1mm}
      \footnotesize{\textsc{Ingnierie des Systmes d'Information et de Communication}
      }\end{center}\end{minipage}
  \vspace*{2cm}
}

\newcommand{\logogip}{
  \begin{minipage}{5cm}\begin{center}
      \vspace{3mm}
      \includegraphics[width=1.5cm]{gip}\\
      \large{\textsc{Option GIP}} \\%\vspace{1mm}\\
      \footnotesize{\textsc{Gnie Informatique\\et Productique}}
    \end{center}\end{minipage}
  \vspace*{2cm}
}

\newcommand{\logoprod}{
  \begin{minipage}{5cm}\begin{center}
      \vspace{4mm}
      \includegraphics[width=1.5cm]{gip}\\
      \large{\textsc{Option :\\Productique}}
    \end{center}\end{minipage}
  \vspace*{2cm}
}

\newcommand{\logoei}{
  \begin{minipage}{5cm}\begin{center}
      \vspace{5mm}
      \includegraphics[width=1.5cm]{ei}\\
      \large{\textsc{Option EI}}\vspace{1mm}\\
      \footnotesize{\textsc{\'Energtique Industrielle}}
    \end{center}\end{minipage}
  \vspace*{2cm}
}

\newcommand{\logochimie}{
  \begin{minipage}{5cm}\begin{center}
      \vspace{5mm}
      \includegraphics[width=1.5cm]{chimie}\\
      \large{\textsc{Option Chimie-E}}\vspace{1mm}\\
      \footnotesize{\textsc{Chimie et Environnement}}
    \end{center}\end{minipage}
  \vspace*{2cm}
}

\newcommand{\logomcm}{
  \begin{minipage}{5.5cm}\begin{center}
      \vspace{1mm}
      \includegraphics[width=1.5cm]{mcm}\\
      \large{\textsc{Option MCM}}\vspace{1mm}\\
      \footnotesize{\textsc{Mcanique et Comportement des Matriaux}}
    \end{center}\end{minipage}
  \vspace*{2cm}
}

\newcommand{\logomq}{
  \begin{minipage}{5cm}\begin{center}
      \vspace{5mm}
      \includegraphics[width=1.5cm]{mq}\\
      \large{\textsc{Option MQ}}\vspace{1mm}\\
      \footnotesize{\textsc{Mtrologie - Qualit}}
    \end{center}\end{minipage}
  \vspace*{2cm}
}

\newcommand{\logotpc}{
  \begin{minipage}{5.5cm}\begin{center}
      \vspace{2mm}
      \includegraphics[width=1.5cm]{tpc}\\
      \large{\textsc{Option TPC}}\vspace{1mm}\\
      \footnotesize{\textsc{Technologie des Polymres et Composites}}
    \end{center}\end{minipage}
  \vspace*{2cm}
}

\newcommand{\logogc}{
  \begin{minipage}{5cm}\begin{center}
      \vspace{5mm}
      \includegraphics[width=1.5cm]{gc}\\
      \large{\textsc{Option GC}}\vspace{1mm}\\
      \footnotesize{\textsc{Gnie Civil}}
    \end{center}\end{minipage}
  \vspace*{2cm}
}


%%%%%%%%%%%%%%%%%%%%%%% 
%%% Page de titre
%%%%%%%%%%%%%%%%%%%%%%% 

\newcommand{\pagedetitre}{%
  \begin{titlepage}
    \begin{minipage}{16cm}
      \@logos
      \begin{center}

        \decoration{2mm}{
          \begin{minipage}{12cm}
            \begin{center}
              \vspace{1cm}
              \huge{\textsc{\@titre}}\\\LARGE{\textsf{\@societe}~\@ville}
              \\\vspace{0.2cm}
              \large{\@periode}
              \vspace{1cm}
            \end{center}
          \end{minipage}
        }

        \vspace*{1.5cm}
        \Large{\textit{\@auteur}~\@promo}
        \vspace{1cm}\\
        \ifphoto
        \includegraphics[height=\@photosize]{\@titlephotoname}
        \fi
      \end{center}
    \end{minipage}
    \newpage
    \thispagestyle{empty}
    ~
  \end{titlepage}
  \setcounter{page}{3}
}




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%%% Dfinition des chapitres                           %%%
%%% Svrement copi de la classe "rapport" de latexfr %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% Si c'est recto-verso, on gre l'ouverture des chapitres sur les pages impaires
% a part la premire ligne le reste c'est du copier-coller de report.cls
\renewcommand\chapter{\if@openright\newpage{\pagestyle{empty}\cleardoublepage}\else\clearpage\fi
  \thispagestyle{plain}%
  \global\@topnum\z@
  \@afterindentfalse
  \secdef\@chapter\@schapter}

% Dcoration des chapitres.
\def\@makechapterhead#1{%
  \thispagestyle{plain}
  {\parindent \z@ \raggedright \normalfont
    \interlinepenalty\@M
    \centering{%
      \setlength{\fboxsep}{12pt}
      % Cadre
      \decoration{5mm}{
        % Titre du chapitre
        \begin{minipage}{14.5cm}
          \Huge \scshape #1 \hfill%
          \ifnum \c@secnumdepth >\m@ne%
          \Huge \itshape \thechapter \hspace*{0.5mm}%
          \fi%
        \end{minipage}
      }
    } % Fin du \centering
    \vspace*{1cm}
    \vskip 20\p@
  }
}

%%%%%%
% Glossaire, affiche le glossaire  l'endroit indiqu, option: titre
%%%%%%

\renewcommand{\nomlabel}[1]{\textbf{#1}~:\hfil}

% si un jour on veux changer la mise en page du glossaire
\renewcommand{\theglossary}{%

  \nompreamble
  \list{}{%
    \leftmargin\labelwidth
    \advance\leftmargin\labelsep
    \itemsep\nomitemsep
    \let\makelabel\nomlabel}
}

\newcommand{\afficheglossaire}[1]{
  \if@openright\newpage{\pagestyle{empty}\cleardoublepage}\else\clearpage\fi
  \thispagestyle{plain}
\markboth{\MakeUppercase{#1}}{}
  \centering{
    \setlength{\fboxsep}{12pt}
    \decoration{5mm}{
      \begin{minipage}{14.5cm}
        \Huge \scshape #1 \hfill%
      \end{minipage}
    }
    \vspace*{1.5cm}
  }
  \addcontentsline{toc}{chapter}{#1}
  \printglossary 
}


%%%%%%%
% Titre de la table des matires
%%%%%%%

\renewcommand{\tableofcontents}{%
  \if@twocolumn
  \@restonecoltrue\onecolumn
  \else
  \@restonecolfalse
  \fi

  \thispagestyle{plain}
%\markboth{\scshape \contentsname}{\htitre}
\markboth{\MakeUppercase\contentsname}{}
  {\parindent \z@ \raggedright \normalfont
    \interlinepenalty\@M
    \centering{%
      \setlength{\fboxsep}{12pt}
      % Cadre
      \decoration{5mm}{
        % Titre
        \begin{minipage}{14.5cm}
          \Huge \scshape \contentsname \hfill%
        \end{minipage}
      }
    } % Fin du \centering
    \vspace*{1cm}
    \vskip 20\p@
  }

  \@starttoc{toc}%
  \if@restonecol\twocolumn\fi
}


%%%%%%%% FIN DU STYLE %%%%%%%%%%
