#!/bin/bash

#
# Install script for the "emd" LaTeX class and its Lyx layout.
# Script d'install de la classe LaTeX "emd" et de son layout Lyx
# 11/05/2003     Aurelien Bompard <gauret@free.fr>
#

### Configuration ###

SET_LYX_IN_FRENCH=0

#####################

user=$(whoami)


# Regle lyx en francais
function set_lyx_preferences() {
    if [ -f ~/.lyx/preferences ]; then  # Il y a un fichier de pref
	used_lang=$(grep '\\default_language ' ~/.lyx/preferences)
	if [ $? == 0 ]; then  # La langue est reglee...
	    echo "$used_lang" | grep french > /dev/null
	    if [ $? == 0 ]; then  # ...au francais ! -> OK 
		return 0
	    else  # ...a une autre langue. Changer en francais
		perl -pi -e 's/^\\default_language .*$/\\default_language frenchb/g' ~/.lyx/preferences
		return 0
	    fi
        else  # La langue n'est pas reglee -> on la regle
	    echo '\default_language frenchb' >> ~/.lyx/preferences
	    return 0
        fi
    else  # le fichier n'existe pas -> on le cree et on regle la langue
	echo '\default_language frenchb' >> ~/.lyx/preferences
	return 0
    fi
    return 1  # On ne devrait pas arriver ici -> erreur
}

# Installs Lyx layout in ~/.lyx/layouts
function install_layout() {
    install -d ~/.lyx/layouts
    install emd.layout ~/.lyx/layouts/
    echo "Patientez SVP..."
    cd ~/.lyx/
    /usr/share/lyx/configure >/dev/null
    cd -
    echo "Si LyX est lanc, vous devez le redmarrer"
}


# Installs LaTeX class in the user directory
function install_class_user() {
    install -d ~/texmf/tex/latex/emd/
    install -m 644 emd.cls ~/texmf/tex/latex/emd/
    texhash >/dev/null 2>&1
}


# Installs LaTeX class for all users
function install_class_all() {
    echo "Vous allez devoir entrer le mot de passe de root"
    su -c "install -d /usr/share/texmf/tex/latex/emd && install emd.cls /usr/share/texmf/tex/latex/emd && texhash >/dev/null 2>&1"
    [ $? == 0 ] && return 0
    return 1
}



### MAIN ###

echo
echo "----------------------------------------"
echo " Installation de la classe LaTeX \"emd\""
echo "----------------------------------------"


# Type d'installation
type_install=""
while [ "$type_install" != "c" -a "$type_install" != "t" ]; do
    echo
    echo "Voulez vous installer la classe pour l'utilisateur Courant ou pour Tous les utilisateurs ? (c/t)"
    read type_install
done

if [ "$type_install" == "c" ]; then
    install_class_user
fi
if [ "$type_install" == "t" ]; then
    install_class_all
fi


# Lyx
use_lyx=""
while [ "$use_lyx" != "o" -a "$use_lyx" != "n" ]; do
    echo
    echo "Utilisez-vous lyx ? (o/n)"
    read use_lyx
done

if [ "$use_lyx" == "n" ]; then
    echo "Installation termine"
    exit 0
fi

# On utilise Lyx

install_layout

# En franais ?
if [ "$SET_LYX_IN_FRENCH" == "1" ]; then
    set_lyx_preferences
fi

echo "Installation termine"

exit 0

# EOF
